@@ -28,9 +28,9 @@ import gettext
 
 from SystrayNanny import SystrayNanny
 
-icons_files_dir= os.path.join("/usr","share/icons/hicolor")
+icons_files_dir= os.path.join("/usr/local","share/icons/hicolor")
 
 GETTEXT_DOMAIN = 'nanny'
-locale_dir = os.path.join("/usr", "share/" ,"locale/")
+locale_dir = os.path.join("/usr/local", "share/" ,"locale/")
 gettext.bindtextdomain(GETTEXT_DOMAIN, locale_dir)
 gettext.textdomain(GETTEXT_DOMAIN)
